@@ -17,10 +17,4 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with pytest-redis. If not, see <http://www.gnu.org/licenses/>.
 """Main module for pytest-redis."""
-
-import logging
-
-__version__ = '1.2.1'
-
-
-logger = logging.getLogger(__name__)
+__version__ = "2.1.1"
